@@ -1146,13 +1146,13 @@ class MiscConTests(unittest.TestCase):
         L = -1.0
         U = 5.0
         model.cL = Constraint(expr=model.x**2 >= L)
-        self.assertEqual(model.cL.lslack(), -5.0)
+        self.assertEqual(model.cL.lslack(), 5.0)
         self.assertEqual(model.cL.uslack(), float('inf'))
         model.cU = Constraint(expr=model.x**2 <= U)
         self.assertEqual(model.cU.lslack(), float('-inf'))
         self.assertEqual(model.cU.uslack(), 1.0)
         model.cR = Constraint(expr=L <= model.x**2 <= U)
-        self.assertEqual(model.cR.lslack(), -5.0)
+        self.assertEqual(model.cR.lslack(), 5.0)
         self.assertEqual(model.cR.uslack(), 1.0)
 
     def test_constructor(self):
