@@ -30,7 +30,7 @@ class TestSimpleVar(unittest.TestCase):
 
         names = set()
         for var in m.x[:]:
-            names.add(var.cname(True))
+            names.add(var.name)
         self.assertEqual(names, set(['x']))
 
     def test1(self):
@@ -40,7 +40,7 @@ class TestSimpleVar(unittest.TestCase):
 
         names = set()
         for var in m.x[:]:
-            names.add(var.cname(True))
+            names.add(var.name)
         self.assertEqual(names, set(['x[0]', 'x[1]', 'x[2]']))
 
     def test2a(self):
@@ -50,7 +50,7 @@ class TestSimpleVar(unittest.TestCase):
 
         names = set()
         for var in m.x[:, 1]:
-            names.add(var.cname(True))
+            names.add(var.name)
         self.assertEqual(names, set(['x[0,1]', 'x[1,1]', 'x[2,1]']))
 
     def test2b(self):
@@ -60,7 +60,7 @@ class TestSimpleVar(unittest.TestCase):
 
         names = set()
         for var in m.x[2, :]:
-            names.add(var.cname(True))
+            names.add(var.name)
         self.assertEqual(names, set(['x[2,0]', 'x[2,1]', 'x[2,2]']))
 
     def test2c(self):
@@ -70,7 +70,7 @@ class TestSimpleVar(unittest.TestCase):
 
         names = set()
         for var in m.x[3, :]:
-            names.add(var.cname(True))
+            names.add(var.name)
         self.assertEqual(names, set())
 
     def test3a(self):
@@ -80,7 +80,7 @@ class TestSimpleVar(unittest.TestCase):
 
         names = set()
         for var in m.x[:, 1, :]:
-            names.add(var.cname(True))
+            names.add(var.name)
         self.assertEqual(names, set(['x[0,1,0]', 'x[0,1,1]', 'x[0,1,2]', 'x[1,1,0]', 'x[1,1,1]', 'x[1,1,2]', 'x[2,1,0]', 'x[2,1,1]', 'x[2,1,2]' ]))
 
     def test3b(self):
@@ -90,7 +90,7 @@ class TestSimpleVar(unittest.TestCase):
 
         names = set()
         for var in m.x[0, :, 2]:
-            names.add(var.cname(True))
+            names.add(var.name)
         self.assertEqual(names, set(['x[0,0,2]', 'x[0,1,2]', 'x[0,2,2]']))
 
 
